"use strict";
/**
 * response.ts
 * Copyright(c) 2021 Aaron Hedges <aaron@dashron.com>
 * MIT Licensed
 *
 * The response object contains all of the information you want to send to the client.
 * 	This includes the body, status code and all applicable headers.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.wrap = void 0;
class Response {
    /**
     * Creates a new Response object.
     *
     * @param {string | Buffer} body - Your response body
     * @param {number} [status] - Your response status
     * @param {object} [headers] - Your response headers
     */
    constructor(body, status, headers) {
        this.body = body;
        this.status = status || 200;
        this.headers = headers || {};
    }
}
exports.default = Response;
/**
 * Wraps the return value of a promise in a Response object to ensure consistency.
 *
 * @param {Promise<Response | string>} promise
 * @returns {Promise<unknown>}
 */
function wrap(promise) {
    return promise.then((routeResponse) => {
        return routeResponse instanceof Response ? routeResponse : new Response(routeResponse);
    });
}
exports.wrap = wrap;
