"use strict";
/**
 * parseBody.ts
 * Copyright(c) 2021 Aaron Hedges <aaron@dashron.com>
 * MIT Licensed
 *
 * Exposes a single middleware function to help parse request bodies
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.middleware = void 0;
const contentTypeModule = require("content-type");
const qsModule = require("querystring");
function getSingleHeader(headers, key) {
    if (headers) {
        // This is a little weirder than I would like, but it works better with typescript
        const val = headers[key];
        if (Array.isArray(val)) {
            return val[0];
        }
        return val;
    }
}
/**
 * Translate the request body into a usable value.
 *
 * If the content type is application/json this will attempt to parse that json
 * If application/x-www-form-urlencoded this will attempt to parse it as a query format
 * Otherwise this will return a string
 *
 * @param  {string} body - request body
 * @param  {string} content_type - media type of the body
 * @returns {(object|string)} parsed body
 * @todo Actually do something with the parameters, such as charset
 */
function parseRequestBody(body, contentType) {
    if (contentType) {
        const parsedContentType = contentTypeModule.parse(contentType);
        if (parsedContentType.type === 'application/json') {
            // parse json
            return JSON.parse(body);
        }
        else if (parsedContentType.type === 'application/x-www-form-urlencoded') {
            // parse form encoded
            return qsModule.parse(body);
        }
    }
    // maybe it's supposed to be literal
    return body;
}
/**
 * Attempts the parse the request body into a useful object
 */
const middleware = function (method, url, body, headers, next) {
    this.body = parseRequestBody(body, getSingleHeader(headers, 'content-type'));
    return next();
};
exports.middleware = middleware;
