"use strict";
/**
 * reroute.ts
 * Copyright(c) 2021 Aaron Hedges <aaron@dashron.com>
 * MIT Licensed
 *
 * Applies a method to the request context that allows you to make requests into another roads object.
 * This is useful when you're running two servers locally. One example is a webserver and a separate API server.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.build = void 0;
/**
 * Applies a method to the request context that allows you to make requests into another roads object.
 * This is useful when you're running two servers locally. One example is a webserver and a separate API server.
 *
 * TODO: Should this just use applytocontext?
 *
 * @param {string} key - The name of the key in the request context that will store the roads request.
 * @param  {road} road - The roads object that you will interact with.
 * @return {function} The middleware function. This value should be passed to road.use(fn);
 */
function build(key, road) {
    const reroute = function (route_method, route_path, route_body, route_headers, next) {
        this[key] = function (method, path, body, headers) {
            if (!headers) {
                headers = {};
            }
            return road.request(method, path, body, headers);
        };
        return next();
    };
    return reroute;
}
exports.build = build;
