"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint-disable @typescript-eslint/no-explicit-any */
const cookieMiddleware_1 = require("../../../middleware/cookieMiddleware");
const response_1 = require("../../../core/response");
describe('cookie tests', () => {
    test('test cookie middleware parses cookies into context', () => {
        expect.assertions(2);
        const context = {
            Response: response_1.default
        };
        cookieMiddleware_1.serverMiddleware.call(context, 'a', 'b', 'c', {
            cookie: 'foo=bar;abc=def'
        }, function () { return Promise.resolve('test'); });
        expect(context.getCookies().foo).toEqual('bar');
        expect(context.getCookies().abc).toEqual('def');
    });
    test('test cookie middleware will update the response headers', () => {
        expect.assertions(1);
        const context = {
            Response: response_1.default
        };
        const next = function () {
            this.setCookie('foo', 'bar');
            return Promise.resolve('test');
        };
        // eslint-disable-next-line @typescript-eslint/no-empty-function
        expect(cookieMiddleware_1.serverMiddleware.call(context, 'a', 'b', 'c', {}, next.bind(context)))
            .resolves.toEqual(new response_1.default('test', 200, {
            'Set-Cookie': ['foo=bar']
        }));
    });
    test('test that getCookies merges new and old cookies together and properly sets outgoing header', () => {
        expect.assertions(2);
        const context = {
            Response: response_1.default
        };
        const next = function () {
            this.setCookie('foo', 'bar');
            expect(this.getCookies()).toEqual({
                foo: 'bar',
                abc: 'def'
            });
            return Promise.resolve('test');
        };
        expect(cookieMiddleware_1.serverMiddleware.call(context, 'a', 'b', 'c', {
            cookie: 'abc=def'
        }, next.bind(context)))
            .resolves.toEqual(new response_1.default('test', 200, {
            'Set-Cookie': ['foo=bar']
        }));
    });
    test('test that getCookies still works with clientCookies', () => {
        expect.assertions(2);
        const context = {
            Response: response_1.default
        };
        const testDocument = {
            cookie: 'foo=bar;abc=def'
        };
        (0, cookieMiddleware_1.buildClientMiddleware)(testDocument).call(context, 'a', 'b', 'c', {}, function () { return Promise.resolve('test'); });
        expect(context.getCookies().foo).toEqual('bar');
        expect(context.getCookies().abc).toEqual('def');
    });
    test('test that setCookies still works with clientCookies', () => __awaiter(void 0, void 0, void 0, function* () {
        expect.assertions(1);
        const context = {
            Response: response_1.default
        };
        const testDocument = {
            cookie: ''
        };
        const next = function () {
            this.setCookie('foo', 'bar');
            return Promise.resolve('test');
        };
        yield (0, cookieMiddleware_1.buildClientMiddleware)(testDocument).call(context, 'a', 'b', 'c', {}, next.bind(context));
        expect(testDocument.cookie).toEqual('foo=bar');
    }));
    test('test that getCookies merges new and old cookies together and properly sets document', () => __awaiter(void 0, void 0, void 0, function* () {
        expect.assertions(2);
        const context = {
            Response: response_1.default
        };
        const next = function () {
            this.setCookie('foo', 'bar');
            expect(this.getCookies()).toEqual({
                foo: 'bar',
                abc: 'def'
            });
            return Promise.resolve('test');
        };
        const testDocument = {
            cookie: 'abc=def'
        };
        yield (0, cookieMiddleware_1.buildClientMiddleware)(testDocument).call(context, 'a', 'b', 'c', {
            // This is overridden by the document cookies. I think we want this? :shrug:. easy to fix in the future if not
            cookie: 'ignored=andDropped'
        }, next.bind(context));
        expect(testDocument.cookie).toEqual('foo=bar');
    }));
});
