"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.port = void 0;
/* eslint-disable @typescript-eslint/no-explicit-any */
const http = require("http");
exports.port = 8081;
// creates an http server specifically for testing this request library
function createServer() {
    return new Promise((resolve, reject) => {
        const server = http.createServer();
        let body = '';
        let bodyFound = false;
        server.on('request', (request, response) => {
            // Get all the streaming input data from the request
            request.on('readable', () => {
                bodyFound = true;
                let chunk = null;
                while (null !== (chunk = request.read())) {
                    body += chunk;
                }
            });
            // When the request stops sending data, wrap it all up and find the proper API response
            request.on('end', () => {
                if (!bodyFound) {
                    body = undefined;
                }
                const routerResponse = router(request.method, request.url)(body, request.headers);
                response.writeHead(routerResponse.status, routerResponse.headers ? routerResponse.headers : {});
                if (typeof routerResponse.body !== 'undefined') {
                    response.write(routerResponse.body);
                }
                response.end();
            });
            // Handle any errors
            request.on('error', (err) => {
                throw err;
            });
        });
        server.listen(exports.port, () => {
            resolve(server);
        });
        server.on('error', (err) => {
            reject(err);
        });
    });
}
exports.default = createServer;
// Formatting help for building the responses interpreted by this test http server
function buildResponse(status, headers, body) {
    return {
        status: status,
        headers: headers,
        body: body
    };
}
/**
 * List of all test routes
 */
const routes = {
    '/': {
        GET: (body, headers) => {
            return {
                status: 200,
                headers: {
                    'this-is': 'for real',
                    'content-type': 'application/json'
                },
                body: JSON.stringify({
                    url: '/',
                    method: 'GET',
                    body: body,
                    headers: headers,
                    message: 'hello!'
                })
            };
        },
        POST: (body, headers) => {
            return {
                status: 200,
                headers: {
                    'content-type': 'application/json'
                },
                body: JSON.stringify({
                    url: '/',
                    method: 'POST',
                    body: body,
                    headers: headers,
                    message: 'hello!'
                })
            };
        }
    }
};
/**
 * Function to help locate test routes
 *
 * @param {*} method
 * @param {*} url
 */
function router(method, url) {
    if (routes[url] && routes[url][method]) {
        return routes[url][method];
    }
    return () => {
        return buildResponse(404, {}, 'Page not found');
    };
}
